"""
@generated by codestare-proto-plus.  Do not edit manually!
"""
from proto import (
    DOUBLE,
    Field,
    module,
)

from proto.message import (
    Message,
)


__protobuf__ = module(
    package="ubii.proto.v1",
    manifest={
        "Color",
    }
)


class Color(Message):
    """Generated from ubii/proto/v1/dataStructure/color.proto

    Attributes:
        r (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        g (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        b (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

        a (proto.fields.Field): :obj:`~proto.fields.Field` of type
            :obj:`~proto.DOUBLE`

    """

    r = Field(
        DOUBLE,
        number=1,
    )
    g = Field(
        DOUBLE,
        number=2,
    )
    b = Field(
        DOUBLE,
        number=3,
    )
    a = Field(
        DOUBLE,
        number=4,
    )

